@@ -34,7 +34,7 @@ def replace_expired_token(func):
 def default_headers(user_email):
     return {
         'content-type': 'application/json',
-        'Accept': 'application/json; version=1',
+        'Accept': 'application/json; version=2',
         'X-User-Email': user_email,
     }
 
@@ -105,6 +105,29 @@ class Base:
 
         return res
 
+    @staticmethod
+    # TODO, Make it validate and return key, value criteria
+    def unique_key_format_result(res, module_name, unique_id=None):
+        if len(res['data']) > 0:
+            data = res['data'][0]
+            info = res['info']
+        else:
+            data = {}
+
+            if unique_id:
+                info = '{0} "{1}" could not be found!'.format(module_name,
+                                                              unique_id)
+            else:
+                info_msg = 'No {0} could be found respecting the specified ' \
+                           'search criteria'
+                info = info_msg.format(module_name)
+
+        res = {'success': res['success'],
+               'info': info,
+               'app_info': res['app_info'],
+               'data': data}
+        return res
+
     @staticmethod
     def response_success(module_name, action, r_content):
         if action == CREATE:
@@ -150,7 +173,8 @@ class Base:
 
     # Method that generates the RESTful API URL
     def get_api_url(self, model_name, api_specifics=''):
-        return self.base_api_url + model_name + str(api_specifics)
+        complete_api_specifics = '{0}{1}'.format(model_name, api_specifics)
+        return '{0}{1}'.format(self.base_api_url, complete_api_specifics)
 
     @replace_expired_token
     def api_get(self, api_url, **kwargs):
@@ -166,7 +190,7 @@ class Base:
 
     @replace_expired_token
     def api_post(self, api_url, **kwargs):
-        """Sends a GET request. Returns :class:`Response` object.
+        """Sends a POST request. Returns :class:`Response` object.
         :param api_url: URL for the new :class:`Request` object.
         :param kwargs: Optional arguments that ``request`` takes.
         """
@@ -178,7 +202,7 @@ class Base:
 
     @replace_expired_token
     def api_put(self, api_url, **kwargs):
-        """Sends a GET request. Returns :class:`Response` object.
+        """Sends a PUT request. Returns :class:`Response` object.
         :param api_url: URL for the new :class:`Request` object.
         :param kwargs: Optional arguments that ``request`` takes.
         """
@@ -190,7 +214,7 @@ class Base:
 
     @replace_expired_token
     def api_delete(self, api_url, **kwargs):
-        """Sends a GET request. Returns :class:`Response` object.
+        """Sends a DELETE request. Returns :class:`Response` object.
         :param api_url: URL for the new :class:`Request` object.
         :param kwargs: Optional arguments that ``request`` takes.
         """
