@@ -22,7 +22,7 @@ class CalibrationClientTest(ModuleBase, unittest.TestCase):
             'data_set_name': 'exp001.cal001',
             'raw_data_location': None,
             'calibration_constant_id': -3,
-            'physical_device_id': -1,
+            'physical_detector_unit_id': -1,
             'flg_deployed': True,
             'flg_good_quality': True,
             'begin_validity_at': '2016-05-24T10:30:14.000+02:00',
@@ -41,7 +41,7 @@ class CalibrationClientTest(ModuleBase, unittest.TestCase):
             'data_set_name': 'exp001.cal001',
             'raw_data_location': None,
             'calibration_constant_id': -3,
-            'physical_device_id': -1,
+            'physical_detector_unit_id': -1,
             'flg_deployed': True,
             'flg_good_quality': True,
             'begin_validity_at': '2016-05-25T10:30:14.000+02:00',
@@ -51,9 +51,10 @@ class CalibrationClientTest(ModuleBase, unittest.TestCase):
             'description': 'Created automatically via seed:seed_tests'}
 
     def test_inject_new_calibration_constant_version(self):
-        calibration_hash_01 = CalibrationTestHash(None).valid_01
+        calibration_hash_01 = CalibrationTestHash(None).valid_inject_01
 
         cal_dict = calibration_hash_01['karabo_h']
+        report_h = cal_dict['report']
         det_cond_h = cal_dict['detector_condition']
         cc_h = cal_dict['calibration_constant']
         ccv_h = cal_dict['calibration_constant_version']
@@ -63,6 +64,7 @@ class CalibrationClientTest(ModuleBase, unittest.TestCase):
         end_val_at_exp = calibration_hash_01['end_validity_at_exp']
 
         cal_inject_dict = {
+            'report': report_h,
             'detector_condition': det_cond_h,
             'calibration_constant': cc_h,
             'calibration_constant_version': ccv_h
@@ -107,15 +109,15 @@ class CalibrationClientTest(ModuleBase, unittest.TestCase):
         assert resp_cc['name'] == cc_h['name']
         assert resp_cc['flg_available'] == True
         assert resp_cc['flg_auto_approve'] == True
-        assert resp_cc['device_type_id'] == -1
+        assert resp_cc['detector_type_id'] == -1
         # assert resp_cc['condition_id'] == -1
         assert resp_cc['calibration_id'] == -1
         assert resp_cc['description'] == cc_h['description']
 
         # Physical Device info
-        resp_pd = resp['data']['physical_device']
+        resp_pd = resp['data']['physical_detector_unit']
         assert resp_pd['id'] == -2
-        assert resp_pd['name'] == ccv_h['device_name']
+        assert resp_pd['physical_name'] == ccv_h['pdu_physical_name']
         assert resp_pd['flg_available'] == True
 
     def test_retrieve_calibration_constant_version(self):
@@ -134,14 +136,13 @@ class CalibrationClientTest(ModuleBase, unittest.TestCase):
         # cal_name = 'CALIBRATION_TEST-2_DO_NOT_DELETE'
         cal_name = calibration_hash_01['karabo_h'][
             'calibration_constant']['calibration_name']
-        # dev_name = 'PHYSICAL_DEVICE-1_DO_NOT_DELETE'
-        dev_name = calibration_hash_01['karabo_h'][
-            'calibration_constant_version']['device_name']
+        # pdu_phy_name = 'PHYSICAL_DETECTOR_UNIT-1_DO_NOT_DELETE'
+        pdu_phy_name = calibration_hash_01['karabo_h'][
+            'calibration_constant_version']['pdu_physical_name']
 
         retrieve_h = {
-            'calibration_hash_schema_version': '1.0',
             'calibration_name': cal_name,
-            'device_name': dev_name,
+            'pdu_physical_name': pdu_phy_name,
             'measured_at': begin_at_exp,  # [Default == now()]
             'snapshot_at': '',  # [Default == now()]
             'detector_condition': det_cond_h_exp
@@ -188,24 +189,27 @@ class CalibrationClientTest(ModuleBase, unittest.TestCase):
                 'flg_auto_approve': True,
                 'flg_available': True,
                 'description': 'Created automatically via seed:seed_tests',
-                'device_type_id': -1, 'calibration_id': -2,
+                'detector_type_id': -1,
+                'calibration_id': -2,
                 'condition_id': -3},
-            'physical_device': {
+            'physical_detector_unit': {
                 'id': -1,
-                'name': 'PHYSICAL_DEVICE-1_DO_NOT_DELETE',
-                'device_type_id': -1, 'flg_available': True,
-                'parent_id': None,
+                'physical_name': 'PHYSICAL_DETECTOR_UNIT-1_DO_NOT_DELETE',
+                'detector_type_id': -1,
+                'flg_available': True,
                 'description': 'Created automatically via seed:seed_tests'}}
 
         assert resp_ccv['name'] == expected_return['name']
         assert resp_ccv['flg_good_quality'] == True
 
-        assert resp_ccv['begin_validity_at'] == expected_return['begin_validity_at']
+        assert resp_ccv['begin_validity_at'] == expected_return[
+            'begin_validity_at']
         assert resp_ccv['end_validity_at'] == expected_return['end_validity_at']
         assert resp_ccv['begin_at'] == expected_return['begin_at']
 
         assert resp_ccv['flg_deployed'] == True
-        assert resp_ccv['raw_data_location'] == expected_return['raw_data_location']
+        assert resp_ccv['raw_data_location'] == expected_return[
+            'raw_data_location']
         assert resp_ccv['file_name'] == expected_return['file_name']
         assert resp_ccv['path_to_file'] == expected_return['path_to_file']
         assert resp_ccv['description'] == expected_return['description']
@@ -221,17 +225,17 @@ class CalibrationClientTest(ModuleBase, unittest.TestCase):
         assert resp_cc['name'] == expected_return_cc['name']
         assert resp_cc['flg_available'] == True
         assert resp_cc['flg_auto_approve'] == True
-        assert resp_cc['device_type_id'] == -1
+        assert resp_cc['detector_type_id'] == -1
         # assert resp_cc['condition_id'] == -1
         assert resp_cc['calibration_id'] == -2
         assert resp_cc['description'] == expected_return_cc['description']
 
         # Physical Device info
-        resp_pd = resp['data']['physical_device']
-        expected_return_pd = expected_return['physical_device']
+        resp_pd = resp['data']['physical_detector_unit']
+        expected_return_pd = expected_return['physical_detector_unit']
 
         assert resp_pd['id'] == -1
-        assert resp_pd['name'] == expected_return_pd['name']
+        assert resp_pd['physical_name'] == expected_return_pd['physical_name']
         assert resp_pd['flg_available'] == True
 
     def test_retrieve_all_calibration_constant_versions(self):
@@ -249,14 +253,13 @@ class CalibrationClientTest(ModuleBase, unittest.TestCase):
         # cal_name = 'CALIBRATION_TEST-2_DO_NOT_DELETE'
         cal_name = calibration_hash_01['karabo_h'][
             'calibration_constant']['calibration_name']
-        # dev_name = 'PHYSICAL_DEVICE-1_DO_NOT_DELETE'
-        dev_name = calibration_hash_01['karabo_h'][
-            'calibration_constant_version']['device_name']
+        # pdu_phy_name = 'PHYSICAL_DETECTOR_UNIT-1_DO_NOT_DELETE'
+        pdu_phy_name = calibration_hash_01['karabo_h'][
+            'calibration_constant_version']['pdu_physical_name']
 
         retrieve_h = {
-            'calibration_hash_schema_version': '1.0',
             'calibration_name': cal_name,
-            'device_name': dev_name,
+            'pdu_physical_name': pdu_phy_name,
             'measured_at': begin_at_exp,  # [Default == now()]
             'snapshot_at': '',  # [Default == now()]
             'detector_condition': det_cond_h_exp
@@ -291,54 +294,68 @@ class CalibrationClientTest(ModuleBase, unittest.TestCase):
         resp_ccv_0 = response_data[0]
 
         assert resp_ccv_0['name'] == self.existing_db_06['name']
-        assert resp_ccv_0['flg_good_quality'] == self.existing_db_06['flg_good_quality']
+        assert resp_ccv_0['flg_good_quality'] == self.existing_db_06[
+            'flg_good_quality']
 
-        assert resp_ccv_0['begin_validity_at'] == self.existing_db_06['begin_validity_at']
-        assert resp_ccv_0['end_validity_at'] == self.existing_db_06['end_validity_at']
+        assert resp_ccv_0['begin_validity_at'] == self.existing_db_06[
+            'begin_validity_at']
+        assert resp_ccv_0['end_validity_at'] == self.existing_db_06[
+            'end_validity_at']
         assert resp_ccv_0['begin_at'] == self.existing_db_06['begin_at']
 
         assert resp_ccv_0['flg_deployed'] == self.existing_db_06['flg_deployed']
-        assert resp_ccv_0['raw_data_location'] == self.existing_db_06['raw_data_location']
+        assert resp_ccv_0['raw_data_location'] == self.existing_db_06[
+            'raw_data_location']
         assert resp_ccv_0['file_name'] == self.existing_db_06['file_name']
         assert resp_ccv_0['path_to_file'] == self.existing_db_06['path_to_file']
         assert resp_ccv_0['description'] == self.existing_db_06['description']
         # Special cases...
-        assert resp_ccv_0['data_set_name'] == self.existing_db_06['data_set_name']
+        assert resp_ccv_0['data_set_name'] == self.existing_db_06[
+            'data_set_name']
         assert resp_ccv_0['start_idx'] == self.existing_db_06['start_idx']
         assert resp_ccv_0['end_idx'] == self.existing_db_06['end_idx']
 
         # Calibration Constant info
-        assert resp_ccv_0['calibration_constant']['id'] == self.existing_db_06['calibration_constant_id']
+        assert resp_ccv_0['calibration_constant']['id'] == self.existing_db_06[
+            'calibration_constant_id']
 
         # Physical Device info
-        assert resp_ccv_0['physical_device']['id'] == self.existing_db_06['physical_device_id']
+        assert resp_ccv_0['physical_detector_unit']['id'] == \
+               self.existing_db_06['physical_detector_unit_id']
 
         #
         # Calibration Constant Version info (position 1)
         resp_ccv_1 = response_data[1]
 
         assert resp_ccv_1['name'] == self.existing_db_05['name']
-        assert resp_ccv_1['flg_good_quality'] == self.existing_db_05['flg_good_quality']
+        assert resp_ccv_1['flg_good_quality'] == self.existing_db_05[
+            'flg_good_quality']
 
-        assert resp_ccv_1['begin_validity_at'] == self.existing_db_05['begin_validity_at']
-        assert resp_ccv_1['end_validity_at'] == self.existing_db_05['end_validity_at']
+        assert resp_ccv_1['begin_validity_at'] == self.existing_db_05[
+            'begin_validity_at']
+        assert resp_ccv_1['end_validity_at'] == self.existing_db_05[
+            'end_validity_at']
         assert resp_ccv_1['begin_at'] == self.existing_db_05['begin_at']
 
         assert resp_ccv_1['flg_deployed'] == self.existing_db_05['flg_deployed']
-        assert resp_ccv_1['raw_data_location'] == self.existing_db_05['raw_data_location']
+        assert resp_ccv_1['raw_data_location'] == self.existing_db_05[
+            'raw_data_location']
         assert resp_ccv_1['file_name'] == self.existing_db_05['file_name']
         assert resp_ccv_1['path_to_file'] == self.existing_db_05['path_to_file']
         assert resp_ccv_1['description'] == self.existing_db_05['description']
         # Special cases...
-        assert resp_ccv_1['data_set_name'] == self.existing_db_05['data_set_name']
+        assert resp_ccv_1['data_set_name'] == self.existing_db_05[
+            'data_set_name']
         assert resp_ccv_1['start_idx'] == self.existing_db_05['start_idx']
         assert resp_ccv_1['end_idx'] == self.existing_db_05['end_idx']
 
         # Calibration Constant info
-        assert resp_ccv_1['calibration_constant']['id'] == self.existing_db_05['calibration_constant_id']
+        assert resp_ccv_1['calibration_constant']['id'] == self.existing_db_05[
+            'calibration_constant_id']
 
         # Physical Device info
-        assert resp_ccv_1['physical_device']['id'] == self.existing_db_05['physical_device_id']
+        assert resp_ccv_1['physical_detector_unit']['id'] == \
+               self.existing_db_05['physical_detector_unit_id']
 
     def test_retrieve_ccv_no_data_found(self):
         calibration_hash_01 = CalibrationTestHash(None).valid_search_01
@@ -355,14 +372,13 @@ class CalibrationClientTest(ModuleBase, unittest.TestCase):
         # cal_name = 'CALIBRATION_TEST-2_DO_NOT_DELETE'
         cal_name = calibration_hash_01['karabo_h'][
             'calibration_constant']['calibration_name']
-        dev_name = 'PHYSICAL_DEVICE-3_DO_NOT_DELETE'
-        # dev_name = calibration_hash_01['karabo_h'][
-        #     'calibration_constant_version']['device_name']
+        pdu_phy_name = 'PHYSICAL_DETECTOR_UNIT-3_DO_NOT_DELETE'
+        # pdu_phy_name = calibration_hash_01['karabo_h'][
+        #     'calibration_constant_version']['pdu_physical_name']
 
         retrieve_h = {
-            'calibration_hash_schema_version': '1.0',
             'calibration_name': cal_name,
-            'device_name': dev_name,
+            'pdu_physical_name': pdu_phy_name,
             # ==================>>>
             # ERROR IS HERE:
             # Because end_validity_at was set to 1 second after the begin_at
