@@ -6,7 +6,7 @@ import unittest
 
 from .module_base import ModuleBase
 from ..common.config_test import (
-    CALIBRATION_CONSTANT_VERSION, PHYSICAL_DEVICE, RESOURCE_NOT_FOUND
+    CALIBRATION_CONSTANT_VERSION, PHYSICAL_DETECTOR_UNIT, RESOURCE_NOT_FOUND
 )
 from ..common import generators
 from ...modules.calibration_constant_version import CalibrationConstantVersion
@@ -27,7 +27,7 @@ class CalibrationConstantVersionTest(ModuleBase, unittest.TestCase):
             'path_to_file': 'path_to_file_1',
             'data_set_name': 'data_set_name_1',
             'calibration_constant_id': -3,
-            'physical_device_id': -1,
+            'physical_detector_unit_id': -1,
             'flg_deployed': True,
             'flg_good_quality': True,
             'begin_validity_at': '2014-05-25T08:30:00.000+02:00',
@@ -36,6 +36,7 @@ class CalibrationConstantVersionTest(ModuleBase, unittest.TestCase):
             'start_idx': 1,
             'end_idx': 2,
             'raw_data_location': 'XFEL/metadata/',
+            'report_id': '',
             'description': 'desc version 01'
         }
 
@@ -50,7 +51,7 @@ class CalibrationConstantVersionTest(ModuleBase, unittest.TestCase):
             'path_to_file': 'path_to_file_1_upd',
             'data_set_name': 'data_set_name_1_upd',
             'calibration_constant_id': -3,
-            'physical_device_id': -1,
+            'physical_detector_unit_id': -1,
             'flg_deployed': False,
             'flg_good_quality': False,
             'begin_validity_at': '2014-06-25T08:30:00.000+02:00',
@@ -59,6 +60,7 @@ class CalibrationConstantVersionTest(ModuleBase, unittest.TestCase):
             'start_idx': 0,
             'end_idx': 1,
             'raw_data_location': 'XFEL/metadata/bck/',
+            'report_id': '',
             'description': 'desc version 01 Updated!'
         }
 
@@ -83,18 +85,17 @@ class CalibrationConstantVersionTest(ModuleBase, unittest.TestCase):
             #     'flg_auto_approve': True,
             #     'flg_available': True,
             #     'description': 'Created automatically via seed:seed_tests',
-            #     'device_type_id': -1,
+            #     'detector_type_id': -1,
             #     'calibration_id': -1,
             #     'condition_id': -1},
             'calibration_constant_id': -1,
-            # 'physical_device': {
+            # 'physical_detector_unit': {
             #     'id': -1,
-            #     'name': 'PHYSICAL_DEVICE-1_DO_NOT_DELETE',
-            #     'device_type_id': -1,
+            #     'name': 'PHYSICAL_DETECTOR_UNIT-1_DO_NOT_DELETE',
+            #     'detector_type_id': -1,
             #     'flg_available': True,
-            #     'parent_id': None,
             #     'description': 'Created automatically via seed:seed_tests'}
-            'physical_device_id': -1}
+            'physical_detector_unit_id': -1}
 
         self.expected_db_04 = {
             'id': -4,
@@ -117,18 +118,17 @@ class CalibrationConstantVersionTest(ModuleBase, unittest.TestCase):
             #     'flg_auto_approve': True,
             #     'flg_available': True,
             #     'description': 'Created automatically via seed:seed_tests',
-            #     'device_type_id': -1,
+            #     'detector_type_id': -1,
             #     'calibration_id': -1,
             #     'condition_id': -2},
             'calibration_constant_id': -2,
-            # 'physical_device': {
+            # 'physical_detector_unit': {
             #     'id': -1,
-            #     'name': 'PHYSICAL_DEVICE-1_DO_NOT_DELETE',
-            #     'device_type_id': -1,
+            #     'name': 'PHYSICAL_DETECTOR_UNIT-1_DO_NOT_DELETE',
+            #     'detector_type_id': -1,
             #     'flg_available': True,
-            #     'parent_id': None,
             #     'description': 'Created automatically via seed:seed_tests'}
-            'physical_device_id': -1}
+            'physical_detector_unit_id': -1}
 
     def test_create_calibration_constant_version(self):
         __begin_at = generators.generate_timestamp_str(0)
@@ -143,7 +143,7 @@ class CalibrationConstantVersionTest(ModuleBase, unittest.TestCase):
             path_to_file=self.ccv_01['path_to_file'],
             data_set_name=self.ccv_01['data_set_name'],
             calibration_constant_id=self.ccv_01['calibration_constant_id'],
-            physical_device_id=self.ccv_01['physical_device_id'],
+            physical_detector_unit_id=self.ccv_01['physical_detector_unit_id'],
             flg_deployed=self.ccv_01['flg_deployed'],
             flg_good_quality=self.ccv_01['flg_good_quality'],
             begin_validity_at=self.ccv_01['begin_validity_at'],
@@ -152,6 +152,7 @@ class CalibrationConstantVersionTest(ModuleBase, unittest.TestCase):
             start_idx=self.ccv_01['start_idx'],
             end_idx=self.ccv_01['end_idx'],
             raw_data_location=self.ccv_01['raw_data_location'],
+            report_id=self.ccv_01['report_id'],
             description=self.ccv_01['description']
         )
 
@@ -165,7 +166,7 @@ class CalibrationConstantVersionTest(ModuleBase, unittest.TestCase):
         ccv_id = calibration_constant_version['id']
         ccv_name = calibration_constant_version['name']
         ccv_cc_id = calibration_constant_version['calibration_constant']['id']
-        ccv_pd_id = calibration_constant_version['physical_device']['id']
+        ccv_pd_id = calibration_constant_version['physical_detector_unit']['id']
 
         #
         # Create duplicated entry (should throw an error)
@@ -197,7 +198,7 @@ class CalibrationConstantVersionTest(ModuleBase, unittest.TestCase):
 
         #
         # Get entry by UK (should succeed)
-        # (calibration_constant_id, physical_device_id, event_at, snapshot_at)
+        # (calibration_constant_id, physical_detector_unit_id, event_at, snapshot_at)
         #
         ccv_event_at = calibration_constant_version['begin_at']
         ccv_snapshot_at = ''  # '' == Now()
@@ -211,17 +212,17 @@ class CalibrationConstantVersionTest(ModuleBase, unittest.TestCase):
 
         #
         # Get entry by UK (should throw an error)
-        # (calibration_constant_id, physical_device_id, event_at, snapshot_at)
+        # (calibration_constant_id, physical_detector_unit_id, event_at, snapshot_at)
         #
         calibration_constant_id = -666
-        physical_device_id = -666
+        physical_detector_unit_id = -666
         ccv_event_at = ''  # '' == Now()
         ccv_snapshot_at = ''  # '' == Now()
 
         res_uk_error = CalibrationConstantVersion.get_by_uk(
             self.cal_client,
             calibration_constant_id,
-            physical_device_id,
+            physical_detector_unit_id,
             ccv_event_at,
             ccv_snapshot_at
         )
@@ -306,12 +307,12 @@ class CalibrationConstantVersionTest(ModuleBase, unittest.TestCase):
         # Search for the closest version
         #
         calibration_constant_ids = [-1, -2]
-        physical_device_id = -1
+        physical_detector_unit_id = -1
         event_at = None
         snapshot_at = None
 
         result1 = CalibrationConstantVersion.get_closest_by_time(
-            self.cal_client, calibration_constant_ids, physical_device_id,
+            self.cal_client, calibration_constant_ids, physical_detector_unit_id,
             event_at, snapshot_at)
 
         # result1 ==>
@@ -339,15 +340,14 @@ class CalibrationConstantVersionTest(ModuleBase, unittest.TestCase):
         #           'flg_auto_approve': True,
         #           'flg_available': True,
         #           'description': 'Created automatically via seed:seed_tests',
-        #           'device_type_id': -1,
+        #           'detector_type_id': -1,
         #           'calibration_id': -1,
         #           'condition_id': -2},
-        #       'physical_device': {
+        #       'physical_detector_unit': {
         #           'id': -1,
-        #           'name': 'PHYSICAL_DEVICE-1_DO_NOT_DELETE',
-        #           'device_type_id': -1,
+        #           'name': 'PHYSICAL_DETECTOR_UNIT-1_DO_NOT_DELETE',
+        #           'detector_type_id': -1,
         #           'flg_available': True,
-        #           'parent_id': None,
         #           'description': 'Created automatically via seed:seed_tests'}
         # }}
 
@@ -358,12 +358,12 @@ class CalibrationConstantVersionTest(ModuleBase, unittest.TestCase):
         # Search for the closest version
         #
         calibration_constant_ids = [-1, -2]
-        physical_device_id = -1
+        physical_detector_unit_id = -1
         event_at = '2014-05-26T12:00:00.000+02:00'
         snapshot_at = None
 
         result1 = CalibrationConstantVersion.get_closest_by_time(
-            self.cal_client, calibration_constant_ids, physical_device_id,
+            self.cal_client, calibration_constant_ids, physical_detector_unit_id,
             event_at, snapshot_at)
 
         # result1 ==>
@@ -391,15 +391,14 @@ class CalibrationConstantVersionTest(ModuleBase, unittest.TestCase):
         #           'flg_auto_approve': True,
         #           'flg_available': True,
         #           'description': 'Created automatically via seed:seed_tests',
-        #           'device_type_id': -1,
+        #           'detector_type_id': -1,
         #           'calibration_id': -1,
         #           'condition_id': -1},
-        #       'physical_device': {
+        #       'physical_detector_unit': {
         #           'id': -1,
-        #           'name': 'PHYSICAL_DEVICE-1_DO_NOT_DELETE',
-        #           'device_type_id': -1,
+        #           'name': 'PHYSICAL_DETECTOR_UNIT-1_DO_NOT_DELETE',
+        #           'detector_type_id': -1,
         #           'flg_available': True,
-        #           'parent_id': None,
         #           'description': 'Created automatically via seed:seed_tests'}
         # }}
 
@@ -410,12 +409,12 @@ class CalibrationConstantVersionTest(ModuleBase, unittest.TestCase):
         # Search for all the version
         #
         calibration_constant_ids = [-1, -2]
-        physical_device_id = -1
+        physical_detector_unit_id = -1
         event_at = None
         snapshot_at = None
 
         result1 = CalibrationConstantVersion.get_all_versions(
-            self.cal_client, calibration_constant_ids, physical_device_id,
+            self.cal_client, calibration_constant_ids, physical_detector_unit_id,
             event_at, snapshot_at)
 
         assert [(d['id'], d['name']) for d in result1['data']] == [
@@ -430,12 +429,12 @@ class CalibrationConstantVersionTest(ModuleBase, unittest.TestCase):
         # Search for all the version
         #
         calibration_constant_ids = [-1, -2]
-        physical_device_id = -1
+        physical_detector_unit_id = -1
         event_at = '2014-05-26T12:00:00.000+02:00'
         snapshot_at = None
 
         result1 = CalibrationConstantVersion.get_all_versions(
-            self.cal_client, calibration_constant_ids, physical_device_id,
+            self.cal_client, calibration_constant_ids, physical_detector_unit_id,
             event_at, snapshot_at)
 
         assert [(d['id'], d['name']) for d in result1['data']] == [
@@ -471,8 +470,8 @@ class CalibrationConstantVersionTest(ModuleBase, unittest.TestCase):
         receive_cc_id = receive['calibration_constant']['id']
         assert receive_cc_id == expect['calibration_constant_id']
 
-        receive_cc_id = receive[PHYSICAL_DEVICE]['id']
-        assert receive_cc_id == expect['physical_device_id']
+        receive_cc_id = receive[PHYSICAL_DETECTOR_UNIT]['id']
+        assert receive_cc_id == expect['physical_detector_unit_id']
 
 
 if __name__ == '__main__':
